@@ -2,7 +2,7 @@ package HTTP::Message;
 
 use strict;
 use vars qw($VERSION $AUTOLOAD);
-$VERSION = "5.827";
+$VERSION = "5.828";
 
 require HTTP::Headers;
 require Carp;
@@ -384,7 +384,7 @@ sub decoded_content
 		$self->content_charset ||
 		"ISO-8859-1"
 	    );
-	    if ($charset ne "none") {
+	    unless ($charset =~ /^(?:none|us-ascii|iso-8859-1)\z/) {
 		require Encode;
 		if (do{my $v = $Encode::VERSION; $v =~ s/_//g; $v} < 2.0901 &&
 		    !$content_ref_iscopy)
